import React from "react";
import { Link } from "react-router-dom";
import { format, isToday } from "date-fns";

import { GlobalInfoStore, ProgramStore } from "stores";

const GlobalStats = () => {
  const { onlineUsers, onlineMembers } = GlobalInfoStore.useState();
  const { currentId, scheduleIds, items } = ProgramStore.useState();

  const nextProgramEntryId = scheduleIds
    ? scheduleIds[currentId ? scheduleIds.indexOf(currentId) + 1 : 0]
    : null;

  const nextProgramEntry = nextProgramEntryId
    ? items[nextProgramEntryId]
    : null;

  return (
    <div className="bg-grey-50 flex space-x-4 leading-normal px-4 py-2 text-xs md:text-sm text-grey-300">
      <div>
        <strong>{onlineMembers}</strong> <span>členů online</span>
      </div>
      <div>
        <strong>{onlineUsers}</strong> <span>online celkem</span>
      </div>
      {nextProgramEntry && (
        <div className="flex-grow text-right hidden sm:block">
          Následuje:{" "}
          <Link to="/program" className="font-bold">
            {nextProgramEntry.title} @{" "}
            {format(
              nextProgramEntry.expectedStartAt,
              isToday(nextProgramEntry.expectedStartAt)
                ? "H:mm"
                : "dd. MM. H:mm"
            )}
          </Link>
        </div>
      )}
    </div>
  );
};

export default GlobalStats;
